clc;
clear all; 

% Load data
load('G_rms_data.mat');
load('O_rms_data.mat');
load('W_rms_data.mat');
load('OW_rms_data.mat');
load('GO_rms_data.mat');
load('GW_rms_data.mat');
load('GOW_rms_data.mat');

%Sampling frequency
fs = 51.2e3;
L = 500;

%X-axis for time vs. amplitude plots
GO_Xvector = linspace(0, length(GO_ae1_data)/fs*1000, length(GO_ae1_data));
GW_Xvector = linspace(0, length(GW_ae1_data)/fs*1000, length(GW_ae1_data));
OW_Xvector = linspace(0, length(OW_ae1_data)/fs*1000, length(OW_ae1_data));
GOW_Xvector = linspace(0, length(GOW_ae1_data)/fs*1000, length(GOW_ae1_data));

%Total volumetric liquid flow
GO_liq_Qv = GO_Oref_Qv;
OW_liq_Qv = OW_Oref_Qv + OW_Wref_Qv;
GW_liq_Qv = GW_Wref_Qv;
GOW_liq_Qv = GOW_Wref_Qv + GOW_Oref_Qv;

%Total volumetric flow
GO_tot_Qv = GO_liq_Qv + GO_Gref_Qv;
OW_tot_Qv = OW_liq_Qv + OW_Gref_Qv;
GW_tot_Qv = GW_liq_Qv + GW_Gref_Qv;
GOW_tot_Qv = GOW_liq_Qv + GOW_Gref_Qv;

%Total differential pressure over test segment
W_tot_dp = W_Pi - W_Po;
O_tot_dp = O_Pi - O_Po;
G_tot_dp = G_Pi - G_Po;
GO_tot_dp = GO_Pi - GO_Po;
OW_tot_dp = OW_Pi - OW_Po;
GW_tot_dp = GW_Pi - GW_Po;
GOW_tot_dp = GOW_Pi - GOW_Po;

%Gas mass flow rate [kg/min]
GO_Gref_Qm = GO_Gref_Qv.*GO_Gref_rho/60;
GW_Gref_Qm = GW_Gref_Qv.*GW_Gref_rho/60;
GOW_Gref_Qm = GOW_Gref_Qv.*GOW_Gref_rho/60;

%Oil mass flow rate [kg/min]
GO_Oref_Qm = GO_Oref_Qv.*GO_Oref_rho/60;
OW_Oref_Qm = OW_Oref_Qv.*OW_Oref_rho/60;
GOW_Oref_Qm = GOW_Oref_Qv.*GOW_Oref_rho/60;

%Water mass flow rate [kg/min]
GW_Wref_Qm = GW_Wref_Qv.*GW_Wref_rho/60;
OW_Wref_Qm = OW_Wref_Qv.*OW_Wref_rho/60;
GOW_Wref_Qm = GOW_Wref_Qv.*GOW_Wref_rho/60;

%Total liquid mas flow
GO_liq_Qm = GO_Oref_Qm;
GW_liq_Qm = GW_Wref_Qm;
OW_liq_Qm = OW_Oref_Qm + OW_Wref_Qm;
GOW_liq_Qm = GOW_Wref_Qv + GOW_Oref_Qv;

%Singlephase RMS plot
figure('Name','Singlephase RMS plot')
subplot(6,1,1)
plot([G_ae1_rms O_ae1_rms W_ae1_rms]);
hold on
plot([G_ae3_rms O_ae3_rms W_ae3_rms]);
plot([G_ae4_rms O_ae4_rms W_ae4_rms]);
hold off
title('Measurements');
legend('Sensor 1','Sensor 3','Sensor 4');
ylabel('[Vrms]');
grid on
set(gca,'xtick',[1:33],'xticklabel',{'G02';'G03';'G04';'G05';'G06';'G07';'G08';'G09';'G10';'G11';'OC01';'OC02';'OC03';'OC04';'OC07';'OC08';'OC09';'OC10';'OC11';'OC12';'OC13';'OC14';'OC16';'OC17';'OC18';'W01';'W02';'W03';'W08';'W09';'W10';'W11';'W12'});
subplot(6,1,2)
plot([G_Gref_Qv O_Oref_Qv W_Wref_Qv]);
title('Flow references');
legend('Total flow');
ylabel('[m3/h]');
grid on
set(gca,'xtick',[1:33],'xticklabel',{'G02';'G03';'G04';'G05';'G06';'G07';'G08';'G09';'G10';'G11';'OC01';'OC02';'OC03';'OC04';'OC07';'OC08';'OC09';'OC10';'OC11';'OC12';'OC13';'OC14';'OC16';'OC17';'OC18';'W01';'W02';'W03';'W08';'W09';'W10';'W11';'W12'});
subplot(6,1,3)
plot([G_HIC O_HIC W_HIC]);
title('Choke valve');
legend('Valve opening');
ylabel('[%]');
grid on
set(gca,'xtick',[1:33],'xticklabel',{'G02';'G03';'G04';'G05';'G06';'G07';'G08';'G09';'G10';'G11';'OC01';'OC02';'OC03';'OC04';'OC07';'OC08';'OC09';'OC10';'OC11';'OC12';'OC13';'OC14';'OC16';'OC17';'OC18';'W01';'W02';'W03';'W08';'W09';'W10';'W11';'W12'});
subplot(6,1,4)
plot([G_tot_dp O_tot_dp W_tot_dp]);
title('Total differential pressure');
legend('Total dp');
ylabel('[bar]');
grid on
set(gca,'xtick',[1:33],'xticklabel',{'G02';'G03';'G04';'G05';'G06';'G07';'G08';'G09';'G10';'G11';'OC01';'OC02';'OC03';'OC04';'OC07';'OC08';'OC09';'OC10';'OC11';'OC12';'OC13';'OC14';'OC16';'OC17';'OC18';'W01';'W02';'W03';'W08';'W09';'W10';'W11';'W12'});
subplot(6,1,5)
plot([G_wikaDp1 O_wikaDp1 W_wikaDp1]);
hold on
plot([G_wikaDp2 O_wikaDp2 W_wikaDp2]);
plot([G_wikaDp3 O_wikaDp3 W_wikaDp3]);
title('Wika venturi');
legend('dp1','dp2','dp3');
ylabel('[mbar]');
grid on
set(gca,'xtick',[1:33],'xticklabel',{'G02';'G03';'G04';'G05';'G06';'G07';'G08';'G09';'G10';'G11';'OC01';'OC02';'OC03';'OC04';'OC07';'OC08';'OC09';'OC10';'OC11';'OC12';'OC13';'OC14';'OC16';'OC17';'OC18';'W01';'W02';'W03';'W08';'W09';'W10';'W11';'W12'});
subplot(6,1,6)
plot([G_EmcoDp1 O_EmcoDp1 W_EmcoDp1]);
hold on
plot([G_EmcoDp2 O_EmcoDp2 W_EmcoDp2]);
title('Emco venturi');
legend('dp1','dp2');
ylabel('[mbar]');
grid on
set(gca,'xtick',[1:33],'xticklabel',{'G02';'G03';'G04';'G05';'G06';'G07';'G08';'G09';'G10';'G11';'OC01';'OC02';'OC03';'OC04';'OC07';'OC08';'OC09';'OC10';'OC11';'OC12';'OC13';'OC14';'OC16';'OC17';'OC18';'W01';'W02';'W03';'W08';'W09';'W10';'W11';'W12'});

%Water and oil RMS plot
figure('Name','OW RMS plot')
subplot(6,1,1)
plot(OW_ae1_rms);
hold on
plot(OW_ae3_rms);
plot(OW_ae4_rms);
hold off
grid on
title('Measurements');
legend('Sensor 1','Sensor 3','Sensor 4');
ylabel('[Vrms]');
grid on
set(gca,'xtick',[1:21],'xticklabel',{'OW01';'OW02';'OW31';'OW04';'OW05';'OW06';'OW17';'OW19';'OW22';'OW23';'OWC10';'OWC11';'OWC12';'OWC13';'OWC14';'OWC15';'OWC16';'OWC17';'OWC18';'OWC19';'OWC20';});
subplot(6,1,2)
plot(OW_Wref_Qv);
hold on
plot(OW_Oref_Qv);
plot(OW_tot_Qv);
title('Flow references');
legend('Water','Oil','Total');
ylabel('[m3/h]');
set(gca,'xtick',[1:21],'xticklabel',{'OW01';'OW02';'OW31';'OW04';'OW05';'OW06';'OW17';'OW19';'OW22';'OW23';'OWC10';'OWC11';'OWC12';'OWC13';'OWC14';'OWC15';'OWC16';'OWC17';'OWC18';'OWC19';'OWC20';});
subplot(6,1,3)
plot(OW_HIC);
title('Choke valve');
legend('Valve opening');
ylim([0,110]);
ylabel('[%]');
grid on
set(gca,'xtick',[1:21],'xticklabel',{'OW01';'OW02';'OW31';'OW04';'OW05';'OW06';'OW17';'OW19';'OW22';'OW23';'OWC10';'OWC11';'OWC12';'OWC13';'OWC14';'OWC15';'OWC16';'OWC17';'OWC18';'OWC19';'OWC20';});
subplot(6,1,4)
plot(OW_tot_dp);
title('Total differential pressure');
legend('Total dp');
ylabel('[bar]');
grid on
set(gca,'xtick',[1:21],'xticklabel',{'OW01';'OW02';'OW31';'OW04';'OW05';'OW06';'OW17';'OW19';'OW22';'OW23';'OWC10';'OWC11';'OWC12';'OWC13';'OWC14';'OWC15';'OWC16';'OWC17';'OWC18';'OWC19';'OWC20';});
subplot(6,1,5)
plot(OW_wikaDp1);
hold on
plot(OW_wikaDp2);
plot(OW_wikaDp3);
title('Wika venturi');
legend('dp1','dp2','dp3');
ylabel('[mbar]');
grid on
set(gca,'xtick',[1:21],'xticklabel',{'OW01';'OW02';'OW31';'OW04';'OW05';'OW06';'OW17';'OW19';'OW22';'OW23';'OWC10';'OWC11';'OWC12';'OWC13';'OWC14';'OWC15';'OWC16';'OWC17';'OWC18';'OWC19';'OWC20';});
subplot(6,1,6)
plot(OW_EmcoDp1);
hold on
plot(OW_EmcoDp2);
title('Emco venturi');
legend('dp1','dp2');
ylabel('[mbar]');
grid on
set(gca,'xtick',[1:21],'xticklabel',{'OW01';'OW02';'OW31';'OW04';'OW05';'OW06';'OW17';'OW19';'OW22';'OW23';'OWC10';'OWC11';'OWC12';'OWC13';'OWC14';'OWC15';'OWC16';'OWC17';'OWC18';'OWC19';'OWC20';});

%Gas and oil RMS plot
figure('Name','GO RMS plot')
subplot(6,1,1)
plot(GO_ae1_rms);
hold on
plot(GO_ae3_rms);
plot(GO_ae4_rms);
hold off
title('Measurements');
legend('Sensor 1','Sensor 3','Sensor 4');
ylabel('[Vrms]');
grid on
set(gca,'xtick',[1:23],'xticklabel',{'GO01';'GO01C';'GO02C';'GO03C';'GO04C';'GO05';'GO05C';'GO06';'GO09';'GO17';'GO18';'GO19';'GO22';'GOC11';'GOC12';'GOC13';'GOC14';'GOC15';'GOC16';'GOC17';'GOC18';'GOC19';'GOC20';});
subplot(6,1,2)
plot(GO_Wref_Qv);
hold on
plot(GO_Oref_Qv);
plot(GO_Gref_Qv);
plot(GO_tot_Qv);
title('Flow references');
legend('Water','Oil','Gas','Total');
ylabel('[m3/h]');
grid on
set(gca,'xtick',[1:23],'xticklabel',{'GO01';'GO01C';'GO02C';'GO03C';'GO04C';'GO05';'GO05C';'GO06';'GO09';'GO17';'GO18';'GO19';'GO22';'GOC11';'GOC12';'GOC13';'GOC14';'GOC15';'GOC16';'GOC17';'GOC18';'GOC19';'GOC20';});
subplot(6,1,3)
plot(GO_HIC);
title('Choke valve');
legend('Valve opening');
ylabel('[%]');
grid on
set(gca,'xtick',[1:23],'xticklabel',{'GO01';'GO01C';'GO02C';'GO03C';'GO04C';'GO05';'GO05C';'GO06';'GO09';'GO17';'GO18';'GO19';'GO22';'GOC11';'GOC12';'GOC13';'GOC14';'GOC15';'GOC16';'GOC17';'GOC18';'GOC19';'GOC20';});
subplot(6,1,4)
plot(GO_tot_dp);
title('Total differential pressure');
legend('Total dp');
ylabel('[bar]');
grid on
set(gca,'xtick',[1:23],'xticklabel',{'GO01';'GO01C';'GO02C';'GO03C';'GO04C';'GO05';'GO05C';'GO06';'GO09';'GO17';'GO18';'GO19';'GO22';'GOC11';'GOC12';'GOC13';'GOC14';'GOC15';'GOC16';'GOC17';'GOC18';'GOC19';'GOC20';});
subplot(6,1,5)
plot(GO_wikaDp1);
hold on
plot(GO_wikaDp2);
plot(GO_wikaDp3);
title('Wika venturi');
legend('dp1','dp2','dp3');
ylabel('[mbar]');
grid on
set(gca,'xtick',[1:23],'xticklabel',{'GO01';'GO01C';'GO02C';'GO03C';'GO04C';'GO05';'GO05C';'GO06';'GO09';'GO17';'GO18';'GO19';'GO22';'GOC11';'GOC12';'GOC13';'GOC14';'GOC15';'GOC16';'GOC17';'GOC18';'GOC19';'GOC20';});
subplot(6,1,6)
plot(GO_EmcoDp1);
hold on
plot(GO_EmcoDp2);
title('Emco venturi');
legend('dp1','dp2');
ylabel('[mbar]');
grid on
set(gca,'xtick',[1:23],'xticklabel',{'GO01';'GO01C';'GO02C';'GO03C';'GO04C';'GO05';'GO05C';'GO06';'GO09';'GO17';'GO18';'GO19';'GO22';'GOC11';'GOC12';'GOC13';'GOC14';'GOC15';'GOC16';'GOC17';'GOC18';'GOC19';'GOC20';});

%Gas and water RMS plot
figure('Name','GW RMS plot')
subplot(6,1,1)
plot(GW_ae1_rms);
hold on
plot(GW_ae3_rms);
plot(GW_ae4_rms);
hold off
title('Measurements');
legend('Sensor 1','Sensor 3','Sensor 4');
ylabel('[Vrms]');
grid on
set(gca,'xtick',[1:6],'xticklabel',{'GW30';'GW31';'GW32';'GW33';'GW34';'GW35';});
subplot(6,1,2)
plot(GW_Wref_Qv);
hold on
plot(GW_Gref_Qv);
plot(GW_tot_Qv);
title('Flow references');
legend('Water','Gas','Total');
ylabel('[m3/h]');
grid on
set(gca,'xtick',[1:6],'xticklabel',{'GW30';'GW31';'GW32';'GW33';'GW34';'GW35';});
subplot(6,1,3)
plot(GW_HIC);
title('Choke valve');
legend('Valve opening');
ylim([0,110]);
ylabel('[%]');
grid on
set(gca,'xtick',[1:6],'xticklabel',{'GW30';'GW31';'GW32';'GW33';'GW34';'GW35';});
subplot(6,1,4)
plot(GW_tot_dp);
title('Differential pressure');
legend('Total dp');
ylabel('[bar]');
grid on
set(gca,'xtick',[1:6],'xticklabel',{'GW30';'GW31';'GW32';'GW33';'GW34';'GW35';});
subplot(6,1,5)
plot(GW_wikaDp1);
hold on
plot(GW_wikaDp2);
plot(GW_wikaDp3);
title('Wika venturi');
legend('dp1','dp2','dp3');
ylabel('[mbar]');
grid on
set(gca,'xtick',[1:6],'xticklabel',{'GW30';'GW31';'GW32';'GW33';'GW34';'GW35';});
subplot(6,1,6)
plot(GW_EmcoDp1);
hold on
plot(GW_EmcoDp2);
title('Emco venturi');
legend('dp1','dp2');
ylabel('[mbar]');
grid on
set(gca,'xtick',[1:6],'xticklabel',{'GW30';'GW31';'GW32';'GW33';'GW34';'GW35';});

%Gas oil and water RMS plot
figure('Name','GOW RMS plot')
subplot(6,1,1)
plot(GOW_ae1_rms);
hold on
plot(GOW_ae3_rms);
plot(GOW_ae4_rms);
hold off
title('Measurements');
legend('Sensor 1','Sensor 3','Sensor 4');
ylabel('[Vrms]');
grid on
set(gca,'xtick',[1:17],'xticklabel',{'GOW1';'GOW2';'GOW3';'GOW4';'GOW5';'GOW6';'GOW7';'GOW8';'GOW9';'GOW10';'GOW102';'GOW102';'GOW103';'GOW104';'GOW105';'GOW106';'GOW107';});
subplot(6,1,2)
plot(GOW_Wref_Qv);
hold on
plot(GOW_Oref_Qv);
plot(GOW_Gref_Qv);
plot(GOW_tot_Qv);
title('Flow references');
legend('Water','Oil','Gas','Total');
ylabel('[m3/h]');
grid on
set(gca,'xtick',[1:17],'xticklabel',{'GOW1';'GOW2';'GOW3';'GOW4';'GOW5';'GOW6';'GOW7';'GOW8';'GOW9';'GOW10';'GOW102';'GOW102';'GOW103';'GOW104';'GOW105';'GOW106';'GOW107';});
subplot(6,1,3)
plot(GOW_HIC);
title('Choke valve');
legend('Valve opening');
ylim([0,110]);
ylabel('[%]');
grid on
set(gca,'xtick',[1:17],'xticklabel',{'GOW1';'GOW2';'GOW3';'GOW4';'GOW5';'GOW6';'GOW7';'GOW8';'GOW9';'GOW10';'GOW102';'GOW102';'GOW103';'GOW104';'GOW105';'GOW106';'GOW107';});
subplot(6,1,4)
plot(GOW_tot_dp);
title('Differential pressure');
legend('Total dp');
ylabel('[bar]');
grid on
set(gca,'xtick',[1:17],'xticklabel',{'GOW1';'GOW2';'GOW3';'GOW4';'GOW5';'GOW6';'GOW7';'GOW8';'GOW9';'GOW10';'GOW102';'GOW102';'GOW103';'GOW104';'GOW105';'GOW106';'GOW107';});
subplot(6,1,5)
plot(GOW_wikaDp1);
hold on
plot(GOW_wikaDp2);
plot(GOW_wikaDp3);
title('Wika venturi');
legend('dp1','dp2','dp3');
ylabel('[mbar]');
grid on
set(gca,'xtick',[1:17],'xticklabel',{'GOW1';'GOW2';'GOW3';'GOW4';'GOW5';'GOW6';'GOW7';'GOW8';'GOW9';'GOW10';'GOW102';'GOW102';'GOW103';'GOW104';'GOW105';'GOW106';'GOW107';});
subplot(6,1,6)
plot(GOW_EmcoDp1);
hold on
plot(GOW_EmcoDp2);
title('Emco venturi');
legend('dp1','dp2');
ylabel('[mbar]');
grid on
set(gca,'xtick',[1:17],'xticklabel',{'GOW1';'GOW2';'GOW3';'GOW4';'GOW5';'GOW6';'GOW7';'GOW8';'GOW9';'GOW10';'GOW102';'GOW102';'GOW103';'GOW104';'GOW105';'GOW106';'GOW107';});

%FREQUENCY ALANSIS----------------------------------------------------------

%Frequency vs. time plots
figure('Name','Hamming window selection for Pwelch method')
subplot(2,1,1);
pwelch(GO_ae1_data,[],[],[],fs);
title('Power spectral density estimate of sensor 1');
subplot(2,1,2);
pwelch(GO_ae1_data,hamming(5000),[],[],fs);
hold on;
pwelch(GO_ae1_data,hamming(500),[],[],fs);
pwelch(GO_ae1_data,hamming(100),[],[],fs);
title('Power spectral density estimate of sensor 1 with Hamming window');
legend('L = 5000', 'L = 500', 'L = 100');

figure('Name','Hamming window selection for Spectogram')
subplot(2,1,1);
spectrogram(GO_ae1_data,[],[],[],fs);
title('Spectrogram using short-time Fourier transform on sensor 1');
subplot(2,1,2);
spectrogram(GO_ae1_data,hamming(500),[],[],fs);
title('Spectrogram using short-time Fourier transform on sensor 1 with Hamming window (L = 500)');

figure('Name','GO frequency analysis')
subplot(3,3,1)
plot(GO_Xvector, GO_ae1_data);
title('Time series plot of the raw value of sensor 1');
xlabel('Time (ms)');
ylabel('Voltage (V)');
ylim([-3 3]);
subplot(3,3,2)
plot(GO_Xvector, GO_ae3_data);
title('Time series plot of the raw value of sensor 3');
xlabel('Time (ms)');
ylabel('Voltage (V)');
ylim([-3 3]);
subplot(3,3,3)
plot(GO_Xvector, GO_ae4_data);
title('Time series plot of the raw value of sensor 4');
xlabel('Time (ms)');
ylabel('Voltage (V)');
ylim([-3 3]);
subplot(3,3,4)
pwelch(GO_ae1_data,hamming(L),[],[],fs);
title('Power spectral density estimate of sensor 1');
ylim([-120 -30]);
subplot(3,3,5)
pwelch(GO_ae3_data,hamming(L),[],[],fs);
title('Power spectral density estimate of sensor 3');
ylim([-120 -30]);
subplot(3,3,6)
pwelch(GO_ae4_data,hamming(L),[],[],fs);
title('Power spectral density estimate of sensor 4');
ylim([-120 -30]);
subplot(3,3,7)
spectrogram(GO_ae1_data,hamming(L),[],[],fs);
title('Spectrogram using short-time Fourier transform on sensor 1');
subplot(3,3,8)
spectrogram(GO_ae3_data,hamming(L),[],[],fs);
title('Spectrogram using short-time Fourier transform on sensor 3');
subplot(3,3,9)
spectrogram(GO_ae4_data,hamming(L),[],[],fs);
title('Spectrogram using short-time Fourier transform on sensor 4');

figure('Name','GW frequency analysis')
subplot(3,3,1)
plot(GW_Xvector, GW_ae1_data);
title('Time series plot of the raw value of sensor 1');
xlabel('Time (ms)');
ylabel('Voltage (V)');
ylim([-3 3]);
subplot(3,3,2)
plot(GW_Xvector, GW_ae3_data);
title('Time series plot of the raw value of sensor 3');
xlabel('Time (ms)');
ylabel('Voltage (V)');
ylim([-3 3]);
subplot(3,3,3)
plot(GW_Xvector, GW_ae4_data);
title('Time series plot of the raw value of sensor 4');
xlabel('Time (ms)');
ylabel('Voltage (V)');
ylim([-3 3]);
subplot(3,3,4)
pwelch(GW_ae1_data,hamming(L),[],[],fs);
title('Power spectral density estimate of sensor 1');
ylim([-120 -30]);
subplot(3,3,5)
pwelch(GW_ae3_data,hamming(L),[],[],fs);
title('Power spectral density estimate of sensor 3');
ylim([-120 -30]);
subplot(3,3,6)
pwelch(GW_ae4_data,hamming(L),[],[],fs);
title('Power spectral density estimate of sensor 4');
ylim([-120 -30]);
subplot(3,3,7)
spectrogram(GW_ae1_data,hamming(L),[],[],fs);
title('Spectrogram using short-time Fourier transform on sensor 1');
subplot(3,3,8)
spectrogram(GW_ae3_data,hamming(L),[],[],fs);
title('Spectrogram using short-time Fourier transform on sensor 3');
subplot(3,3,9)
spectrogram(GW_ae4_data,hamming(L),[],[],fs);
title('Spectrogram using short-time Fourier transform on sensor 4');

figure('Name','OW frequency analysis')
subplot(3,3,1)
plot(OW_Xvector, OW_ae1_data);
title('Time series plot of the raw value of sensor 1');
xlabel('Time (ms)');
ylabel('Voltage (V)');
ylim([-3 3]);
subplot(3,3,2)
plot(OW_Xvector, OW_ae3_data);
title('Time series plot of the raw value of sensor 3');
xlabel('Time (ms)');
ylabel('Voltage (V)');
ylim([-3 3]);
subplot(3,3,3)
plot(OW_Xvector, OW_ae4_data);
title('Time series plot of the raw value of sensor 4');
xlabel('Time (ms)');
ylabel('Voltage (V)');
ylim([-3 3]);
subplot(3,3,4)
pwelch(OW_ae1_data,hamming(L),[],[],fs);
title('Power spectral density estimate of sensor 1');
ylim([-120 -30]);
subplot(3,3,5)
pwelch(OW_ae3_data,hamming(L),[],[],fs);
ylim([-120 -30]);
title('Power spectral density estimate of sensor 3');
subplot(3,3,6)
pwelch(OW_ae4_data,hamming(L),[],[],fs);
title('Power spectral density estimate of sensor 4');
ylim([-120 -30]);
subplot(3,3,7)
spectrogram(OW_ae1_data,hamming(L),[],[],fs);
title('Spectrogram using short-time Fourier transform on sensor 1');
subplot(3,3,8)
spectrogram(OW_ae3_data,hamming(L),[],[],fs);
title('Spectrogram using short-time Fourier transform on sensor 3');
subplot(3,3,9)
spectrogram(OW_ae4_data,hamming(L),[],[],fs);
title('Spectrogram using short-time Fourier transform on sensor 4');

figure('Name','GOW frequency plot')
subplot(3,3,1)
plot(GOW_Xvector, GOW_ae1_data);
title('Time series plot of the raw value of sensor 1');
xlabel('Time (ms)');
ylabel('Voltage (V)');
ylim([-3 3]);
subplot(3,3,2)
plot(GOW_Xvector, GOW_ae3_data);
title('Time series plot of the raw value of sensor 3');
xlabel('Time (ms)');
ylabel('Voltage (V)');
ylim([-3 3]);
subplot(3,3,3)
plot(GOW_Xvector, GOW_ae4_data);
title('Time series plot of the raw value of sensor 4');
xlabel('Time (ms)');
ylabel('Voltage (V)');
ylim([-3 3]);
subplot(3,3,4)
pwelch(GOW_ae1_data,hamming(L),[],[],fs);
title('Power spectral density estimate of sensor 1');
ylim([-120 -30]);
subplot(3,3,5)
pwelch(GOW_ae3_data,hamming(L),[],[],fs);
title('Power spectral density estimate of sensor 3');
ylim([-120 -30]);
subplot(3,3,6)
pwelch(GOW_ae4_data,hamming(L),[],[],fs);
title('Power spectral density estimate of sensor 4');
ylim([-120 -30]);
subplot(3,3,7)
spectrogram(GOW_ae1_data,hamming(L),[],[],fs);
title('Spectrogram using short-time Fourier transform on sensor 1');
subplot(3,3,8)
spectrogram(GOW_ae3_data,hamming(L),[],[],fs);
title('Spectrogram using short-time Fourier transform on sensor 3');
subplot(3,3,9)
spectrogram(GOW_ae4_data,hamming(L),[],[],fs);
title('Spectrogram using short-time Fourier transform on sensor 4');

figure('Name','Plot')
scatter(GO_Gref_Qm, GO_liq_Qm, 'red');
hold on;
scatter(GW_Gref_Qm, GW_liq_Qm, 'green');
scatter(GOW_Gref_Qm, GOW_liq_Qm, 'blue');
hold off;
legend('GO','GW','GOW');
ylabel('Liquid [kg/min]');
xlabel('Gas [kg/min]');
set(gca,'xscale','log');
set(gca,'yscale','log');
yline(13.5);
xline(3);
grid minor
